# based on Fedora package: thanks


Name:		bip
Version:	0.8.9
Release:	%mkrel 8
Summary:	IRC Bouncer (proxy)
Group:		Networking/IRC
License:	GPLv2+
URL:		http://bip.milkypond.org/
Source0:	https://projects.duckcorp.org/attachments/download/61/bip-%{version}.tar.gz
Source1:	bip.logrotate
Source2:	bip.service
Source3:	bip-tmpfiles.conf
Patch0:		bip-conf.patch
# Patches 1 through 7 taken from fedora
Patch1: 0002-Throttle-joins-to-prevent-flooding.patch
# Backports of https://projects.duckcorp.org/issues/350: makes CA mode
# TLS work out of the box
# https://projects.duckcorp.org/projects/bip/repository/revisions/89295ca4b2b89f88b4ce52fd78f0033a34906d90
# https://projects.duckcorp.org/projects/bip/repository/revisions/88242715f489850a1f7cad6064492668c84f5083
Patch2: 0001-check-whether-trust-store-is-a-file-or-directory-in-.patch
Patch3: 0002-allow-for-certificate-store-to-be-unspecified-in-CA-.patch
# Backports of a couple of upstream commits that fix build with OpenSSL
# 1.1
Patch4: 0001-Handle-OpenSSL-version-1.1.patch
Patch5: 0001-X509_OBJECT_new-call-X509err.patch
Patch6: 0001-Check-value-returned-by-X509_OBJECT_new.patch
# Fix some 'const const char' declarations
# https://projects.duckcorp.org/issues/580
Patch7: 0001-Fix-some-const-const-char-declarations.patch
BuildRequires:	pkgconfig(openssl)
BuildRequires:	flex
BuildRequires:	byacc
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
Bip is an IRC proxy, which means it keeps connected to your preferred IRC
servers, can store the logs for you, and even send them back to your IRC
client(s) upon connection.
You may want to use bip to keep your logfiles (in a unique format and on a
unique computer) whatever your client is, when you connect from multiple
workstations, or when you simply want to have a playback of what was said
while you were away.

%prep
%setup -q
%autopatch -p1
iconv -f iso-8859-1 -t utf-8 -o ChangeLog{.utf8,}
mv ChangeLog{.utf8,}

%build
# It generates an error on -Werror so we need to remove it.
perl -i -lape 's/\s+-Werror// if /\AAM_CFLAGS =/' "Makefile.in"
export CFLAGS="%{optflags} -DPIC -fPIC"
%configure
%make CFLAGS="%{optflags} -DPIC -fPIC"

%install
%make_install
# Remove misplaced files
rm -rf %{buildroot}%{_defaultdocdir}/bip
mkdir -p %{buildroot}%{_sysconfdir}
# Install bip.conf
install -m 644 samples/bip.conf %{buildroot}%{_sysconfdir}/bip.conf

# Install logrotate
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
install -m755 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/bip


mkdir -p %{buildroot}%{_localstatedir}/log/bip

# Install systemd service file
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%pre
%_pre_useradd %{name} / /bin/sh

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}


%files
%defattr(0755,root,root,-)
%doc AUTHORS ChangeLog README TODO
%doc samples/bip.vim
%{_bindir}/bip
%{_bindir}/bipmkpw
%{_mandir}/man1/bip.1*
%{_mandir}/man1/bipmkpw.1*
%{_mandir}/man5/bip.conf.5*
%config(noreplace) %{_sysconfdir}/bip.conf
%{_sysconfdir}/logrotate.d/bip
%{_unitdir}/bip.service
%{_tmpfilesdir}/bip.conf
%attr(-,bip,bip) %dir %{_localstatedir}/log/bip


%changelog
* Wed Feb 12 2020 umeabot <umeabot> 0.8.9-8.mga8
+ Revision: 1510730
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Fri Sep 21 2018 umeabot <umeabot> 0.8.9-7.mga7
+ Revision: 1295422
- Mageia 7 Mass Rebuild

* Mon Sep 11 2017 cjw <cjw> 0.8.9-6.mga7
+ Revision: 1152883
- merge patches from fedora (fixes build with openssl 1.1)

* Wed Mar 02 2016 umeabot <umeabot> 0.8.9-5.mga6
+ Revision: 983167
- Rebuild for openssl

* Tue Feb 02 2016 umeabot <umeabot> 0.8.9-4.mga6
+ Revision: 932263
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.8.9-3.mga5
+ Revision: 740805
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8.9-2.mga5
+ Revision: 678158
- Mageia 5 Mass Rebuild

* Sat May 17 2014 shlomif <shlomif> 0.8.9-1.mga5
+ Revision: 623336
- New version 0.8.9

* Thu Nov 21 2013 luigiwalser <luigiwalser> 0.8.8-13.mga4
+ Revision: 552170
- add upstream patch to fix CVE-2013-4550

* Sat Oct 19 2013 umeabot <umeabot> 0.8.8-12.mga4
+ Revision: 522617
- Mageia 4 Mass Rebuild

* Sun Mar 24 2013 colin <colin> 0.8.8-11.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Fri Jan 11 2013 umeabot <umeabot> 0.8.8-10.mga3
+ Revision: 346907
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 0.8.8-9.mga3
+ Revision: 321822
- Add tmpfiles.d support
- Do not package dir in /var/run
- Fix build (yyparse conflicting types patched)

* Mon Sep 10 2012 luigiwalser <luigiwalser> 0.8.8-8.mga3
+ Revision: 292063
- fix postun script (mga #4319)

* Wed Sep 05 2012 luigiwalser <luigiwalser> 0.8.8-7.mga3
+ Revision: 288695
- add upstream patch to fix CVE-2012-0806

* Sat Jul 28 2012 sander85 <sander85> 0.8.8-6.mga3
+ Revision: 275374
- Drop SysVinit support

* Sat Apr 28 2012 tmb <tmb> 0.8.8-5.mga2
+ Revision: 233608
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 0.8.8-4.mga2
+ Revision: 233511
- rebuild for versioned rpm-helper requires

* Wed Apr 18 2012 colin <colin> 0.8.8-3.mga2
+ Revision: 231256
- Fix build and systemd unit.

* Mon Jan 16 2012 dmorgan <dmorgan> 0.8.8-2.mga2
+ Revision: 196688
- Add systemd support ( Fedora)

* Mon May 09 2011 misc <misc> 0.8.8-1.mga1
+ Revision: 96631
- do not restart bip when the package is updated, as this will break
  current connection
- add logrotate file
- update to 0.8.8
  fix download url
  use a macro to create the user
  fix default file attribute
- new website
- imported package bip


* Sun Jan 23 2011 Adam Williamson <awilliamson@mandriva.org> 0.8.7-1mdv2011.0
+ Revision: 632407
- new release 0.8.7

* Fri Sep 24 2010 Funda Wang <fwang@mandriva.org> 0.8.6-1mdv2011.0
+ Revision: 580896
- build with fpic

  + Adam Williamson <awilliamson@mandriva.org>
    - new release 0.8.6

* Wed Apr 21 2010 Funda Wang <fwang@mandriva.org> 0.8.4-2mdv2010.1
+ Revision: 537524
- rebuild

* Wed Dec 16 2009 Jérôme Brenier <incubusss@mandriva.org> 0.8.4-1mdv2010.1
+ Revision: 479598
- new version 0.8.4

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 0.8.0-0.rc1.2mdv2010.0
+ Revision: 436822
- rebuild

* Sat Feb 28 2009 Adam Williamson <awilliamson@mandriva.org> 0.8.0-0.rc1.1mdv2009.1
+ Revision: 346163
- add buildroot
- credit Fedora for initial package
- import bip


